///////////////////////////////////////////////////////////////////////////////
// Name:		Mo(use)Sen(sitive)Pic(ture)But(ton).cpp
// Purpose:     Mouse Sensitive Picture Button
// Author:      emarti, Murat Ozdemir  e-mail: dtemarti<add>gmail<dot>com
// Created:     13.04.2006
// Copyright:   (c) emarti
// Licence:     wxWindows license
///////////////////////////////////////////////////////////////////////////////
#include "wx/wxprec.h" 

#ifdef __BORLANDC__ 
    #pragma hdrstop 
#endif 

#ifndef WX_PRECOMP 
    #include "wx/wx.h" 
#endif 

#include "mosenpicbut.h"

BEGIN_EVENT_TABLE(wxMosenpicButton, wxButton) 
    EVT_ENTER_WINDOW(wxMosenpicButton::In) 
    EVT_LEAVE_WINDOW(wxMosenpicButton::Out) 
    EVT_LEFT_DOWN(wxMosenpicButton::Clicked) 
    EVT_LEFT_UP(wxMosenpicButton::In) 
    EVT_PAINT(wxMosenpicButton::OnPaint) 
END_EVENT_TABLE()

wxMosenpicButton::wxMosenpicButton(wxWindow *parent, wxWindowID id, int x, int y, 
								   const wxBitmap* normalbitmap, const  wxBitmap* overbitmap, const  wxBitmap* clickbitmap) 
                  : wxButton(parent, id, wxEmptyString, wxPoint(x, y), wxDefaultSize, wxBORDER_NONE | wxTRANSPARENT_WINDOW) 
{ 
        m_normalbitmap = new wxBitmap(*normalbitmap);
        m_overbitmap =  new wxBitmap(*overbitmap);
        m_clickbitmap =  new wxBitmap(*clickbitmap);
        m_bitmap =  new wxBitmap(*normalbitmap);
        
        m_size = wxSize(m_bitmap->GetWidth(), m_bitmap->GetHeight()); 
        SetSize(wxSize(m_size.x, m_size.y)); 
} 

wxMosenpicButton::~wxMosenpicButton() 
{ 
        if(m_bitmap) 
        { 
            delete m_bitmap;
            m_bitmap = (wxBitmap *) NULL;  
        }
        
        if(m_normalbitmap)
        {    
            delete m_normalbitmap;
            m_normalbitmap = (wxBitmap *) NULL;
        }    
         
        if(m_overbitmap)
        { 
            delete m_overbitmap;
            m_overbitmap = (wxBitmap *) NULL;
        }
        
        if(m_clickbitmap)
        {
            delete m_clickbitmap;
            m_clickbitmap = (wxBitmap *) NULL;
        }   
			
} 

void wxMosenpicButton::In(wxMouseEvent& event) 
{ 
        if(m_bitmap) 
        { 
                delete m_bitmap; 
                if(event.LeftIsDown()) 
                        m_bitmap = new wxBitmap(*m_clickbitmap);
                else 
                        m_bitmap = new wxBitmap(*m_overbitmap);
                Refresh(); 
        } 
        event.Skip(); 
} 

void wxMosenpicButton::Out(wxMouseEvent& event) 
{ 
        if(m_bitmap) 
        { 
                delete m_bitmap; 
                m_bitmap = new wxBitmap(*m_normalbitmap);
                Refresh(); 
        } 
        event.Skip(); 
} 

void wxMosenpicButton::Clicked(wxMouseEvent& event) 
{ 
        if(m_bitmap) 
        { 
                delete m_bitmap; 
                m_bitmap = new wxBitmap(*m_clickbitmap);
                Refresh(); 
        } 
        event.Skip(); 
} 

void wxMosenpicButton::OnPaint(wxPaintEvent& WXUNUSED(event)) 
{ 
        wxPaintDC dc(this); 

        if(m_bitmap && m_bitmap->Ok()) 
        { 
                wxMemoryDC mDC; 
                mDC.SelectObject(*m_bitmap); 
                dc.Blit(0, 0, m_size.x, m_size.y, &mDC, 0, 0, wxCOPY, true); 
                mDC.SelectObject(wxNullBitmap); 
        } 
} 
 
